/*
 * gulkan
 * Copyright 2018 Collabora Ltd.
 * Author: Lubosz Sarnecki <lubosz.sarnecki@collabora.com>
 * SPDX-License-Identifier: MIT
 */

#ifndef GULKAN_VERSION_H
#define GULKAN_VERSION_H

#if !defined(GULKAN_INSIDE) && !defined(GULKAN_COMPILATION)
# error "Only <gulkan.h> can be included directly."
#endif

/**
 * SECTION:gulkanversion
 * @short_description: gulkan version checking
 *
 * gulkan provides macros to check the version of the library
 * at compile-time
 */

/**
 * GULKAN_MAJOR_VERSION:
 *
 * gulkan major version component (e.g. 1 if %GULKAN_VERSION is 1.2.3)
 */
#define GULKAN_MAJOR_VERSION (0)

/**
 * GULKAN_MINOR_VERSION:
 *
 * gulkan minor version component (e.g. 2 if %GULKAN_VERSION is 1.2.3)
 */
#define GULKAN_MINOR_VERSION (15)

/**
 * GULKAN_MICRO_VERSION:
 *
 * gulkan micro version component (e.g. 3 if %GULKAN_VERSION is 1.2.3)
 */
#define GULKAN_MICRO_VERSION (1)

/**
 * GULKAN_VERSION
 *
 * gulkan version.
 */
#define GULKAN_VERSION (0.15.1)

/**
 * GULKAN_VERSION_S:
 *
 * gulkan version, encoded as a string, useful for printing and
 * concatenation.
 */
#define GULKAN_VERSION_S "0.15.1"

#define GULKAN_ENCODE_VERSION(major,minor,micro) \
        ((major) << 24 | (minor) << 16 | (micro) << 8)

/**
 * GULKAN_VERSION_HEX:
 *
 * gulkan version, encoded as an hexadecimal number, useful for
 * integer comparisons.
 */
#define GULKAN_VERSION_HEX \
        (GULKAN_ENCODE_VERSION (GULKAN_MAJOR_VERSION, GULKAN_MINOR_VERSION, GULKAN_MICRO_VERSION))

/**
 * GULKAN_CHECK_VERSION:
 * @major: required major version
 * @minor: required minor version
 * @micro: required micro version
 *
 * Compile-time version checking. Evaluates to %TRUE if the version
 * of gulkan is greater than the required one.
 */
#define GULKAN_CHECK_VERSION(major,minor,micro)   \
        (GULKAN_MAJOR_VERSION > (major) || \
         (GULKAN_MAJOR_VERSION == (major) && GULKAN_MINOR_VERSION > (minor)) || \
         (GULKAN_MAJOR_VERSION == (major) && GULKAN_MINOR_VERSION == (minor) && \
          GULKAN_MICRO_VERSION >= (micro)))

#endif /* GULKAN_VERSION_H */

